@@ -25,7 +25,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kwineffects.h>
 #include <KActionCollection>
 #include <kaction.h>
-#include <klocale.h>
+#include <KDE/KLocalizedString>
 #include <kconfiggroup.h>
 
 namespace KWin
